% -------------------------------------------------------------------------
% Data for numerical experiments.
%
% Output:
% Nt,Nx,Mu ................................... 1x1 dimensions
% x .......................................... (Nx+2)x1 spatial grid
% t .......................................... 1xNt time grid
% X,T ........................................ (Nx+2)xNt surf grid
% dx,dt ...................................... 1x1 step sizes
% M .......................................... NxxNx mass matrix
% A .......................................... NxxNx stiffness matrix
% B .......................................... NxxMu control operator
% f .......................................... NxxNt inhomogeneity
% y0 ......................................... Nxx1 initial value
% yQ ......................................... NxxNt desired state
% yOm ........................................ Nxx1 desired final state
% u0 ......................................... MuxNt initial control
% ua,ub ...................................... MuxNt control bounds
% lmax ....................................... 1x1 maximal POD basis rank
% kmax ....................................... 1x1 maximal iteration number
% eps ........................................ 1x1 desired exactness
% sigma ...................................... 1x1 regularization parameter
% -------------------------------------------------------------------------

fprintf('load input data ...\n')
% geom data                                           % -------------------
Nt = 300; Nx = 148; Mu = 10;                          % Nt,Nx,Mu ...... 1x1
x = linspace(0,2,Nx+2)';                              % x ........ (Nx+2)x1
t = linspace(0,3,Nt);                                 % t ............ 1xNt
T = repmat(t,Nx+2,1); X = repmat(x,1,Nt);             % T,X ..... (Nx+2)xNt
dx = x(2)-x(1); dt = t(2)-t(1);                       % dx,dt ......... 1x1
% init data                                           % -------------------
InitChi = zeros(Nx+2,size(Mu,1));                     % chi ..... (Nx+2)xMu
for i = 1:Mu                                          % begin ......... for
  InitChi((Nx+2)/Mu*(i-1)+1:(Nx+2)/Mu*i,i) = 1;       % chi(.,;) ..... 1xMu
end                                                   % end ........... for
InitF = (T-X.^3);                                     % f ....... (Nx+2)xNt
InitY0 = sum(InitChi(:,3:5),2)-sum(InitChi(:,6:8),2); % y0 ....... (Nx+2)x1
InitYQ = (-(X-1).^2+1).*T;                            % y{Q} .... (Nx+2)xNt
InitYOm = (-(x-1).^2+1)*t(end);                       % y{Om} .... (Nx+2)x1
% pde data                                            % -------------------
d = ones(Nx,1);                                       % d ............ Nxx1
M = dx/6*spdiags([d,4*d,d],-1:1,Nx,Nx);               % M ........... NxxNx
A = 1/dx*spdiags([-d,2*d,-d],-1:1,Nx,Nx);             % A ........... NxxNx
B = M*InitChi(2:end-1,:);                             % B ........... NxxMu
f = M*InitF(2:end-1,:);                               % f ........... NxxNt
y0 = M*InitY0(2:end-1,1);                             % y0 ........... Nxx1
yQ = M*InitYQ(2:end-1,:);                             % yQ .......... NxxNt
yOm = 0*M*InitYOm(2:end-1,1);                           % yOm .......... Nxx1
% opt data                                            % -------------------
u0 = zeros(Mu,Nt);                                    % u0 .......... MuxNt
for i = 1:Mu                                          % begin ......... for
  u0(i,:) = sin(i*pi*t);                              % u0(.,:) ...... 1xNt
end                                                   % end ........... for
ua = .25*ones(Mu,Nt); ub = .75*ones(Mu,Nt);           % ua,ub ....... MuxNt
lmax = 50; kmax = 100;                                % lmax,kmax ..... 1x1
eps = 1.0e-15; sigma = 1.0e-01;                       % eps,sigma ..... 1x1
% clear unused variables                              % -------------------
clearvars d InitChi InitF InitY0 InitYQ InitYOm i     % vars ........ clear
fprintf('input data loaded ...\n')

% -------------------------------------------------------------------------
% Martin Gubisch
% 12.09.2013 --- 18:00